#include<malloc.h>
#include<string.h>
#include<stdio.h>
#include<time.h>
#include<winsock2.h>

typedef unsigned char u_char;
typedef unsigned short u_short;
typedef unsigned int u_int;
/* 4 bytes IP address */
typedef struct ip_address{
    u_char byte1;
    u_char byte2;
    u_char byte3;
    u_char byte4;
}ip_address;

/* 12 bytes network definition */
typedef struct networkdef{
    u_int net;
    u_int mask;
    networkdef *next;
}networkdef;

/* tempstruct header*/
typedef struct period_e{
    u_int ips;             // source ip
    u_int ipd;             // destination ip
    u_short ports;         // Source port
    u_short portd;         // Destination port
    u_char proto;          // higher protocol
    u_int size;            // sum of packet sizes
    u_int packets;         // amount of packets
}period_e;

typedef struct statelem{
	u_int ip;              // host ip
	u_short port, myport;  // host port and my port
	u_char proto;          // ip protocol number
	u_int packets_in,packets_out; // packets count
	u_int traf_in_l,traf_in_h,traf_out_l,traf_out_h; // traffic in and out present by two dword
	statelem *next;        // link to next statistics ip
}statelem;

#define TREND_LENGTH 1000

typedef struct trend{
	u_int time[TREND_LENGTH],in[TREND_LENGTH],out[TREND_LENGTH],count;
	trend * next;
}trend;

typedef struct statarea{
	char name[100];
	statelem * se; //stats queue
	networkdef * nd; //area definition
	trend * tren; //traffic graph
	statarea * next; //next area
}statarea;

statelem * statother = NULL;  // one more area for those not defined
trend * trendother = NULL;  // one more trend for those not defined
statarea * sa = NULL;// first point for statistics
networkdef * myarea;
int minusport = 1,minusmyport = 1,minusname = 1,minusproto = 1,granularity = 1;
u_int time_from = 0,time_till = 0x7FFFFFFF,files_time_from = 0x7FFFFFFF,files_time_till = 0;

int makeareas(FILE *f);
int getstats(FILE *f);
u_int taketime(char *s);

int main(int argc,char * argv[])
{
	if(argc < 3){printf("USAGE: %s <nets file> <logfile1> [+ <logfile2> + ...]\n\t[-g <granularity>(in seconds)][+myport] [+port] [+proto] [+name]\n\t[-from <yy.mm.dd-hh:mm>] [-till <yy.mm.dd-hh:mm>]\n",argv[0]); return 0;}
	FILE * f; if(NULL ==(f = fopen(argv[1],"rb"))){printf("can't open file %s\n",argv[1]); return 1;};
	if(!makeareas(f)){printf("error while processing nets file %s\n",argv[1]); return 1;}
	fclose(f);
	u_int i,logfiles = 1;
	unsigned __int64 z1,z2; // for output of numbers much then 4G
	struct tm *ltime;
	char timestr[256];
	i = 3;
	while((i + 1) < (u_int)argc)
	{
		if(strcmp(argv[i],"+")!=0)break;
		i+=2;
		logfiles++;
	}
	while(i < (u_int)argc)
	{
		if(strcmp(argv[i],"+port")==0)minusport = 0;
		else if(strcmp(argv[i],"+name")==0)minusname = 0;
		else if(strcmp(argv[i],"+myport")==0)minusmyport = 0;
		else if(strcmp(argv[i],"+proto")==0)minusproto = 0;
		else if(strcmp(argv[i],"-g")==0)
		{
			i++; 
			if(i>=(u_int)argc)
				printf("error:can't take granularity parameter\n");
			else
				granularity = atoi(argv[i]);
		}
		else if(strcmp(argv[i],"-from")==0)
		{
			i++; 
			if(i>=(u_int)argc)
				printf("error:can't take time_from parameter\n");
			else
				time_from = taketime(argv[i]);
		}
		else if(strcmp(argv[i],"-till")==0)
		{
			i++; 
			if(i>=(u_int)argc)
				printf("error:can't take time_till parameter\n");
			else
				time_till = taketime(argv[i]);
		}
		else printf("error:argument %s not anderstood\n",argv[i]);
		i++;
	}
	hostent *he;
	statarea *p1,*p;
	networkdef *nd;
	trend *tr;
	p1 = p = sa;
	while(NULL != p) // search for area "log"
	{
		if(strcmp(p->name,"log") == 0)
		{
			myarea = p->nd;
			if(p!=sa)p1->next = p->next; else sa = p->next; //remove log area from statareas
			break;
		}
		p1 = p;
		p = p1->next;
	}
	if(NULL == myarea) //if no [log] section in net file, log the ip 127.0.0.1
	{
		printf("no log network defined in %s - using 127.0.0.1",argv[1]);
		myarea = (networkdef *)malloc(sizeof(networkdef));
		myarea->net = 0x0100007F;
		myarea->mask = 0xFFFFFFFF;
		myarea->next = NULL;
	}
	i = 2;
	while(i <= (0 + 2*logfiles)) //process each devlog file
	{
		if(NULL !=(f = fopen(argv[i],"rb")))
		{
			if(!getstats(f))printf("error while getting stats from %s\n",argv[i]); //processing stats file
		}
		else printf("can't open devlog file %s\n",argv[i]);
		i += 2;
	}
	printf("from\ttill\tfile_from\tfile_till\n");
	ltime = localtime((long *)&time_from); strftime( timestr, sizeof timestr, "%y-%m-%d %H:%M:%S", ltime);
	printf("%s",timestr);
	ltime = localtime((long *)&time_till); strftime( timestr, sizeof timestr, "%y-%m-%d %H:%M:%S", ltime);
	printf("\t%s",timestr);
	ltime = localtime((long *)&files_time_from); strftime( timestr, sizeof timestr, "%y-%m-%d %H:%M:%S", ltime);
	printf("\t%s",timestr);
	ltime = localtime((long *)&files_time_till); strftime( timestr, sizeof timestr, "%y-%m-%d %H:%M:%S", ltime);
	printf("\t%s\n",timestr);
	statelem *sel,summary;
	p = sa;
	if(!minusname)
	{
		WORD wVersionRequested;
		WSADATA wsaData;
		wVersionRequested = MAKEWORD( 2, 2 );
		if(0 != WSAStartup( wVersionRequested, &wsaData )) {printf("can't initialize winsock, names will not be resolved\n"); minusname = 1;}
	}
	while(NULL != p)
	{
		printf("area name:%s\n",p->name);
		nd = p->nd;
		while(NULL != nd)
		{
			printf("\t%d.%d.%d.%d\t%d.%d.%d.%d\n",*(u_char *)(&nd->net),*((u_char *)(&nd->net)+1),*((u_char *)(&nd->net)+2),*((u_char *)(&nd->net)+3),
				*((u_char *)(&nd->mask)),*((u_char *)(&nd->mask)+1),*((u_char *)(&nd->mask)+2),*((u_char *)(&nd->mask)+3));
			nd = nd->next;
		}
		printf("ip");if(!minusport)printf("\tport");if(!minusmyport)printf("\tmy_port");if(!minusproto)printf("\tproto");
		printf("\tpackets_in\ttraffic_in\tpackets_out\ttraffic_out");if(!minusname)printf("\tname");
		printf("\n");
		summary.ip = summary.packets_in = summary.packets_out = summary.traf_in_h = summary.traf_in_l = 
			summary.traf_out_h = summary.traf_out_l = 0;
		sel = p->se;
		while(NULL != sel)
		{
			printf("%d.%d.%d.%d",*(u_char *)(&sel->ip),*((u_char *)(&sel->ip)+1),*((u_char *)(&sel->ip)+2),*((u_char *)(&sel->ip)+3));
			if(!minusport)printf("\t%d",(int)sel->port);
			if(!minusmyport)printf("\t%d",(int)sel->myport);
			if(!minusproto)printf("\t%d",sel->proto);
			z1 = sel->traf_in_h * 0x100000000 + sel->traf_in_l; z2 = sel->traf_out_h * 0x100000000 + sel->traf_out_l;
			printf("\t%u\t%I64u\t%u\t%I64u",sel->packets_in,z1,sel->packets_out,z2);
			if(!minusname)
			{
				fflush(stdout);
				he = (hostent *)gethostbyaddr((char *)&sel->ip,4,AF_INET);
				if(he != NULL)printf("\t%s",he->h_name);
				else printf("\t<->");
			}
			printf("\n");
			summary.ip++;
			summary.traf_in_h += sel->traf_in_h; summary.traf_in_l += sel->traf_in_l; if(summary.traf_in_l < sel->traf_in_l)summary.traf_in_h++;
			summary.traf_out_h += sel->traf_out_h; summary.traf_out_l += sel->traf_out_l; if(summary.traf_out_l < sel->traf_out_l)summary.traf_out_h++;
			summary.packets_in += sel->packets_in; summary.packets_out += sel->packets_out;
			sel = sel->next;
		}
		printf("summary of:%u",summary.ip);if(!minusport)printf("\t");if(!minusmyport)printf("\t");if(!minusproto)printf("\t");
		z1 = summary.traf_in_h * 0x100000000 + summary.traf_in_l; z2 = summary.traf_out_h * 0x100000000 + summary.traf_out_l;
		printf("\t%u\t%I64u\t%u\t%I64u\n",summary.packets_in,z1,summary.packets_out,z2);
		printf("time period\ttraffic_in\ttraffic_out\n");
		tr = p->tren;
		while(tr != NULL)
		{
			for(i = 0;i <= tr->count;i++)
			{
				ltime = localtime((long *)&tr->time[i]);
				strftime( timestr, sizeof timestr, "%y-%m-%d %H:%M:%S", ltime);
				printf("%s\t%u\t%u\n",timestr,tr->in[i],tr->out[i]);
			}
			tr = tr->next;
		}
		p = p->next;
	}
	printf("others:\n");
	printf("ip");if(!minusport)printf("\tport");if(!minusmyport)printf("\tmy_port");if(!minusproto)printf("\tproto");
	printf("\tpackets_in\ttraffic_in\tpackets_out\ttraffic_out");if(!minusname)printf("\tname");
	printf("\n");
	summary.ip = summary.packets_in = summary.packets_out = summary.traf_in_h = summary.traf_in_l = 
		summary.traf_out_h = summary.traf_out_l = 0;
	sel = statother;
	while(NULL != sel)
	{
		printf("%d.%d.%d.%d",*(u_char *)(&sel->ip),*((u_char *)(&sel->ip)+1),*((u_char *)(&sel->ip)+2),*((u_char *)(&sel->ip)+3));
		if(!minusport)printf("\t%d",(int)sel->port);
		if(!minusmyport)printf("\t%d",(int)sel->myport);
		if(!minusproto)printf("\t%d",sel->proto);
		z1 = sel->traf_in_h * 0x100000000 + sel->traf_in_l; z2 = sel->traf_out_h * 0x100000000 + sel->traf_out_l;
		printf("\t%u\t%I64u\t%u\t%I64u",sel->packets_in,z1,sel->packets_out,z2);
		if(!minusname)
		{
			fflush(stdout);
			he = (hostent *)gethostbyaddr((char *)&sel->ip,4,AF_INET);
			if(he != NULL)printf("\t%s",he->h_name);
			else printf("\t<->");
		}
		printf("\n");
		summary.ip++;
		summary.traf_in_h += sel->traf_in_h; summary.traf_in_l += sel->traf_in_l; if(summary.traf_in_l < sel->traf_in_l)summary.traf_in_h++;
		summary.traf_out_h += sel->traf_out_h; summary.traf_out_l += sel->traf_out_l; if(summary.traf_out_l < sel->traf_out_l)summary.traf_out_h++;
		summary.packets_in += sel->packets_in; summary.packets_out += sel->packets_out;
		sel = sel->next;
	}
	printf("summary of:%u",summary.ip);if(!minusport)printf("\t");if(!minusmyport)printf("\t");if(!minusproto)printf("\t");
	z1 = summary.traf_in_h * 0x100000000 + summary.traf_in_l; z2 = summary.traf_out_h * 0x100000000 + summary.traf_out_l;
	printf("\t%u\t%I64u\t%u\t%I64u\n",summary.packets_in,z1,summary.packets_out,z2);
	printf("time period\ttraffic_in\ttraffic_out\n");
	tr = trendother;
	while(tr != NULL)
	{
		for(i = 0;i <= tr->count;i++)
		{
			ltime = localtime((long *)&tr->time[i]);
			strftime( timestr, sizeof timestr, "%y-%m-%d %H:%M:%S", ltime);
			printf("%s\t%u\t%u\n",timestr,tr->in[i],tr->out[i]);
		}
		tr = tr->next;
	}
	return 1;
}

u_int taketime(char *s)
{
	struct tm ltime;
	memset(&ltime,0,sizeof(ltime)); ltime.tm_isdst = 1;
	int i=0,k = 0,j = 0;
	ltime.tm_year = 100;
	while((s[i] >= '0')&&(s[i] <= '9'))i++; if(s[i] == 0)j = 1;
	s[i] = 0; ltime.tm_year = 100 + atoi(s+k); i++; k = i; if(j) goto fin;
	while((s[i] >= '0')&&(s[i] <= '9'))i++;	if(s[i] == 0) j = 1;
	s[i] = 0; ltime.tm_mon = atoi(s+k) - 1; i++; k = i; if(j) goto fin;
	while((s[i] >= '0')&&(s[i] <= '9'))i++;	if(s[i] == 0) j = 1;
	s[i] = 0; ltime.tm_mday = atoi(s+k); i++; k = i; if(j) goto fin;
	while((s[i] >= '0')&&(s[i] <= '9'))i++;	if(s[i] == 0) j = 1;
	s[i] = 0; ltime.tm_hour = atoi(s+k); i++; k = i; if(j) goto fin;
	while((s[i] >= '0')&&(s[i] <= '9'))i++;	if(s[i] == 0) j = 1;
	s[i] = 0; ltime.tm_min = atoi(s+k); i++; k = i; if(j) goto fin;
	while((s[i] >= '0')&&(s[i] <= '9'))i++;	s[i] = 0; ltime.tm_sec = atoi(s+k);
fin:
	return mktime(&ltime);
}

int makeareas(FILE *f)
{
	if(NULL != sa){printf("statarea already touched\n"); return 0;}
	sa = (statarea *)malloc(sizeof(statarea));
	statarea *p = sa;
	networkdef *pnd;
	p->nd = NULL; p->next = NULL; p->se = NULL; p->name[0] = 0; p->tren = NULL;
	fseek(f,0,SEEK_SET);
	int i;
	u_int j;
	char c;
	u_int pip;
	char s[100];
getsection:
	while(!feof(f))
	{
		c = getc(f);
		if((c == ';')||(c == '#'))
		{
			while(10 != (c = getc(f))) if(feof(f))break;
		}
		if(c == '[') //begin of reading section name
		{
			i = 0;
			while(!feof(f))
			{
				c = getc(f);
				if(c == ']'){s[i] = 0; strcpy(p->name,s); goto getndefs;} //successful read of section name
				if(((c == '#')||(c == ';'))||(c == 10))goto getsection;  //eol or comment found
				s[i] = c; i++;
				if(i > 99) i = 99; //if section name longer than 100, truncate
			}
		}
	}
	goto eofoccured;
getndefs:
	while(!feof(f))
	{
		c = getc(f);
		if((c == ';')||(c == '#'))
		{
			while(10 != (c = getc(f))) if(feof(f))break;
		}
		if(c == '[') //begin of reading section name
		{
			i = 0;
			while(!feof(f))
			{
				c = getc(f);
				if(c == ']') //successful read of section name
				{
					s[i] = 0; 
					p->next = (statarea *)malloc(sizeof(statarea));
					p = p->next;
					p->nd = NULL; p->next = NULL; p->se = NULL; p->tren = NULL;
					strcpy(p->name,s); goto getndefs;
				} 
				if(((c == '#')||(c == ';'))||(c == 10))goto getndefs;  //eol or comment found
				s[i] = c; i++;
				if(i > 99) i = 99; //if section name longer than 100, truncate
			}
		}
		if((c<='9')&&(c>='0')) //suppose, network definition found,procceed reading of "<num>.<num>.<num>.<num>/<num>"
		{
			j = (c - '0');
			while(!feof(f)) //ip byte 1
			{
				c = getc(f); 
				if(c == '.'){pip = (j & 0xFF); j = 0; goto probyte2;}
				if((c<='9')&&(c>='0')){j*=10;j+=(c-'0');} else goto getndefs; //if not cifer and not '.' - go read next
			}
			goto eofoccured;
probyte2:
			while(!feof(f)) //ip byte 2
			{
				c = getc(f); 
				if(c == '.'){pip += (j & 0xFF) << 8; j = 0; goto probyte3;}
				if((c<='9')&&(c>='0')){j*=10;j+=(c-'0');} else goto getndefs; //if not cifer and not '.' - go read next
			}
			goto eofoccured;
probyte3:
			while(!feof(f)) //ip byte 3
			{
				c = getc(f); 
				if(c == '.'){pip += (j & 0xFF) << 16; j = 0; goto probyte4;}
				if((c<='9')&&(c>='0')){j*=10;j+=(c-'0');} else goto getndefs; //if not cifer and not '.' - go read next
			}
			goto eofoccured;
probyte4:
			while(!feof(f)) //ip byte 4
			{
				c = getc(f); 
				if(c == '/'){pip += (j & 0xFF) << 24; j = 0; goto promask;}
				if((c<='9')&&(c>='0')){j*=10;j+=(c-'0');} else goto getndefs; //if not cifer and not '/' - go read next
			}
			goto eofoccured;
promask:
			while(!feof(f)) //mask
			{
				c = getc(f); 
				if((c<='9')&&(c>='0')){j*=10;j+=(c-'0');} 
				else //if not cifer - finish network definition
				{
					i = j;                                              // -  -  /n  
					if(i >= 24){j = 0x00FFFFFF + ((0xFF << (56-i)) & 0xFF000000);}
					else if(i >=16){j = 0x0000FFFF + (0x00FFFFFF & (0xFF << (40 - i)));}
					else if(i >= 8){j = 0x000000FF + (0x0000FFFF & (0xFF << (24 - i)));}
					else{j = 0x000000FF & (0xFF << (8 - i));}
					if(p->nd == NULL) //if no definition yet
					{
						p->nd = (networkdef *)malloc(sizeof(networkdef)); p->nd->next = NULL; pnd = p->nd;
						pnd->net = pip; pnd->mask = j;
					}
					else
					{
						while(pnd->next != NULL) pnd = pnd->next; //go to last definition
						pnd->next = (networkdef *)malloc(sizeof(networkdef)); pnd->next->next = NULL; pnd = pnd->next;
						pnd->net = pip; pnd->mask = j;
					}
					if((c == ';')||(c == '#'))while(!feof(f)){c = getc(f); if(c == 10) break;}; //if comment - go to eol
					goto getndefs; 
				}
			}
			goto eofoccured;
		}
	}
eofoccured:
	return 1;
}

int getstats(FILE *f)
{
	period_e p;
	statelem e,*r,*r1;
	statarea *t;
	networkdef *k;
	trend * tr;
	int match;
	u_int time,amount,i;
	time = amount = 0;
	fread(&time,1,4,f); fread(&amount,1,2,f);
	while(!feof(f))
	{
		if(time > files_time_till)files_time_till = time;
		if(time < files_time_from)files_time_from = time;
		if((time > time_till)||(time < time_from))fseek(f,sizeof(period_e)*amount,SEEK_CUR); //skip if not in time period
		else
		for(i = 0;i < amount;i++)
		{
			if(feof(f)){printf("eof in %d ,sooner then expected\n",ftell(f)); return 1;}
			fread(&p,1,sizeof(period_e),f);
			e.packets_in = e.packets_out = 0;
			e.traf_in_h = e.traf_in_l = 0;
			e.traf_out_h = e.traf_out_l = 0;
			if((p.ipd & myarea->mask) == myarea->net)
			{
				e.ip = p.ips;
				e.port = p.ports;
				e.myport = p.portd;
				e.packets_in += p.packets;
				e.traf_in_l += p.size;
				e.proto = p.proto;
			}
			if((p.ips & myarea->mask) == myarea->net)
			{
				e.ip = p.ipd;
				e.port = p.portd;
				e.myport = p.ports;
				e.packets_out += p.packets;
				e.traf_out_l += p.size;
				e.proto = p.proto;
			}
			if((e.packets_in) || (e.packets_out)) // insert in statistics
			{
				match = 0;
				t = sa;
				while(t != NULL) // selection on areas
				{
					k = t->nd;
					while(k != NULL) //selection on nets
					{
						if((e.ip & k->mask) == k->net) //match - insert ip
						{
							match = 1;
							if(t->tren == NULL)
							{
								t->tren = (trend *)malloc(sizeof(trend));
								t->tren->count = 0;
								t->tren->in[0] = t->tren->out[0] = 0;
								t->tren->time[0] = time;
								t->tren->next = NULL;
							}
							tr = t->tren;
							while(tr->next != NULL) tr = tr->next;
							if(time >= (tr->time[tr->count] + granularity))
							{
								if(tr->count >= (TREND_LENGTH -1))
								{
									tr->next = (trend *)malloc(sizeof(trend));
									tr = tr->next;
									tr->count = 0;
									tr->in[0] = 0;
									tr->out[0] = 0;
									tr->time[0] = time;
									tr->next = NULL;
								}
								else
								{
									tr->count++;
									tr->in[tr->count] = 0;
									tr->out[tr->count] = 0;
									tr->time[tr->count] = time;
								}
							}
							tr->in[tr->count] += e.traf_in_l;
							tr->out[tr->count] += e.traf_out_l;
							if(t->se == NULL)
							{
								t->se = (statelem *)malloc(sizeof(statelem));
								memcpy(t->se,&e,sizeof(statelem));
								t->se->next = NULL;
							}
							else
							{
								r = t->se;
								while(r != NULL)
								{
									if((r->ip == e.ip) && ((r->myport == e.myport)||minusmyport) && ((r->port == e.port)||minusport) && ((r->proto == e.proto)||minusproto))//match with statelem
									{
										r->packets_in += e.packets_in;
										r->packets_out += e.packets_out;
										r->traf_in_l += e.traf_in_l; if(r->traf_in_l < e.traf_in_l) r->traf_in_h ++;
										r->traf_out_l += e.traf_out_l; if(r->traf_out_l < e.traf_out_l) r->traf_in_h ++;
										break;
									}
									r1 = r;
									r = r1->next;
								}
								if(r == NULL)//if the end of statelems occured
								{
									r1->next = (statelem *)malloc(sizeof(statelem));
									memcpy(r1->next,&e,sizeof(statelem));
									r1->next->next = NULL;
								}
							}
							break; //inserted in this area - go next area
						}
						k = k->next;
					}
					t = t->next;
				}
				if(!match) // if no area matches - insert into "others"
				{
					if(trendother == NULL)
					{
						trendother = (trend *)malloc(sizeof(trend));
						trendother->count = 0;
						trendother->in[0] = trendother->out[0] = 0;
						trendother->time[0] = time;
						trendother->next = NULL;
					}
					tr = trendother;
					while(tr->next != NULL) tr = tr->next;
					if((tr->time[tr->count] + granularity) <= time)
					{
						if(tr->count >= (TREND_LENGTH -1))
						{
							tr->next = (trend *)malloc(sizeof(trend));
							tr = tr->next;
							tr->count = 0;
							tr->in[0] = 0;
							tr->out[0] = 0;
							tr->time[0] = time;
							tr->next = NULL;
						}
						else
						{
							tr->count++;
							tr->in[tr->count] = 0;
							tr->out[tr->count] = 0;
							tr->time[tr->count] = time;
						}
					}
					tr->in[tr->count] += e.traf_in_l;
					tr->out[tr->count] += e.traf_out_l;
					if(statother == NULL)
					{
						statother = (statelem *)malloc(sizeof(statelem));
						memcpy(statother,&e,sizeof(statelem));
						statother->next = NULL;
					}
					else
					{
						r = statother;
						while(r != NULL)
						{
							if((r->ip == e.ip) && ((r->myport == e.myport)||minusmyport) && ((r->port == e.port)||minusport) && ((r->proto == e.proto)||minusproto))//match with statelem
							{
								r->packets_in += e.packets_in;
								r->packets_out += e.packets_out;
								r->traf_in_l += e.traf_in_l; if(r->traf_in_l < e.traf_in_l) r->traf_in_h ++;
								r->traf_out_l += e.traf_out_l; if(r->traf_out_l < e.traf_out_l) r->traf_in_h ++;
								break;
							}
							r1 = r;
							r = r1->next;
						}
						if(r == NULL)//if the end of statelems occured
						{
							r1->next = (statelem *)malloc(sizeof(statelem));
							memcpy(r1->next,&e,sizeof(statelem));
							r1->next->next = NULL;
						}
					};
				}
			}
		}
		time = amount = 0;
		fread(&time,1,4,f); fread(&amount,1,2,f);
	}
	return 1;
}
/*  unsigned int i,amount,time;
	struct tm *ltime;
	char timestr[256];
	if(argc < 2){printf("specify the file to recognize\n"); return 0;}
	char s[256]; for(i = 0;argv[1][i] != 0;i++)s[i] = argv[1][i]; s[i] = '_'; s[i+1] = 0;
	FILE *f,*g;
	period_e p;
	if(NULL == (f = fopen(argv[1],"rb"))){printf("can't open %s for reading\n",argv[1]);return 0;}
	g = fopen(s,"wb");
	printf("size of struct = %d \n",sizeof(period_e));
	while(!feof(f))
	{
		time = 0; amount = 0;
		fread(&time,1,4,f); fread(&amount,1,2,f);
		ltime = localtime((long *)&time);
		strftime( timestr, sizeof timestr, "%y-%m-%d %H:%M:%S", ltime);
		fprintf(g,"%s\n",timestr);
		for(i = 0;i < amount;i++)
		{
			fread(&p,1,sizeof(period_e),f);
			fprintf(g,"%03d.%03d.%03d.%03d\t%-5d\t",((ip_address *)&p.ips)->byte1,
				((ip_address *)&p.ips)->byte2,((ip_address *)&p.ips)->byte3,
				((ip_address *)&p.ips)->byte4,p.ports);
			fprintf(g,"%03d.%03d.%03d.%03d\t%-5d\t",((ip_address *)&p.ipd)->byte1,
				((ip_address *)&p.ipd)->byte2,((ip_address *)&p.ipd)->byte3,
				((ip_address *)&p.ipd)->byte4,p.portd);
			fprintf(g,"%d\t%d\t%d\n",p.proto,p.size,p.packets);
		}
	}
	fcloseall();
	return 0; */
